setInt64 method

void setInt64(
  1. int position,
  2. int value, [
  3. Endian endian = Endian.big
])

Writes a 64-bit signed integer at the specified position without changing the current write position.

endian specifies byte order (defaults to big-endian).

Throws RangeError if position is negative or if position + 8 exceeds the buffer capacity.

Implementation

@pragma('vm:prefer-inline')
@pragma('dart2js:tryInline')
void setInt64(int position, int value, [Endian endian = Endian.big]) {
  _checkRange(value, kMinInt64, kMaxInt64, 'Int64');
  _ws.data.setInt64(position, value, endian);
}