setInt8 method

void setInt8(
  1. int position,
  2. int value
)

Writes an 8-bit signed value at the specified position without changing the current write position.

Throws RangeError if position is negative or if the position + size exceeds the buffer capacity.

Implementation

@pragma('vm:prefer-inline')
@pragma('dart2js:tryInline')
void setInt8(int position, int value) {
  _checkRange(value, -128, 127, 'Int8');
  _ws.data.setInt8(position, value);
}