operator [] method
Returns the byte at the specified absolute index in the buffer.
This allows random access without affecting the current offset.
Example:
final firstByte = reader[0];
Implementation
@pragma('vm:prefer-inline')
@pragma('dart2js:tryInline')
int operator [](int index) => _rs.list[index];